import os
import urllib.parse
import urllib.request


def __init__(self):
    self.svc_ip = os.getenv("svc_ip")
    self.model_id = os.getenv("model_id")
    self.modelApi = os.getenv("modelApi")


def get_model_api(self):
    return self.modelApi


def commit_train_acc(self, acc):
    data = {'modelId': str(self.model_id), "acc": acc}
    data = urllib.parse.urlencode(data).encode('utf-8')
    address = "http://" + str(self.svc_ip) + ":8080/train/addAcc"
    req = urllib.request.Request(url=address, data=data, method='POST')
    response = urllib.request.urlopen(req)
    return response


def commit_validation_acc(self, acc):
    data = {'modelId': str(self.model_id), "validationAccuracy": acc}
    data = urllib.parse.urlencode(data).encode('utf-8')
    address = "http://" + str(self.svc_ip) + ":8080/model/addValidationAcc"
    req = urllib.request.Request(url=address, data=data, method='POST')
    response = urllib.request.urlopen(req)
    return response



import os
import urllib.parse
import urllib.request


def __init__(self):
    self.dataset_id = os.getenv("dataset_id")
    self.dataset_path = None
    self.dataset_tagging = None


def get_dataset_path(self):
    self.dataset_path = '/dataset/' + str(self.dataset_id) + "/dataset"
    return self.dataset_path


def get_tagging_path(self):
    self.dataset_tagging = '/dataset/' + str(self.dataset_id) + '/tagging.txt'
    return self.dataset_tagging




from setuptools import setup, find_packages

setup(
    name="ai_platform_iscas",
    version="0.1",
    author="vicmeng",
    author_email="1137998920@qq.com",
    description="A brief description of your package",
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.7',
)